﻿
using Xamarin.Forms;

namespace crashfix
{
    public partial class BasePage : ContentPage
    {
        private bool _viewHasAppeared;

        public BasePage()
        {
            InitializeComponent();
        }

        protected override void OnBindingContextChanged()
        {
            base.OnBindingContextChanged();

            (BindingContext as BaseViewModel).PropertyChanged += (sender, e) =>
            {
                if (e.PropertyName == nameof(BaseViewModel.IsBusyIndicatorVisible))
                {
                    IsBusyIndicatorVisible = (BindingContext as BaseViewModel).IsBusyIndicatorVisible;
                }
            };
        }

        protected override void OnAppearing()
        {
            // this allows us to navigate back from a push or model without reloading the view and subsequently, the view models
            if (_viewHasAppeared == true) return;

            base.OnAppearing();
            IsBusyIndicatorVisible = false;
            (BindingContext as BaseViewModel).Start();

            _viewHasAppeared = true;
        }

        protected override void OnParentSet()
        {
            base.OnParentSet();

            if (Parent != null)
            {
                //(Parent as NavigationPage).BarBackgroundColor = AppColors.NavigationBarBlue;
                (Parent as NavigationPage).BarTextColor = Color.White;
            }
        }

        public static readonly BindableProperty IsBusyIndicatorVisibleProperty = BindableProperty.Create(nameof(IsBusyIndicatorVisible), typeof(bool), typeof(BasePage), false, BindingMode.TwoWay);
        public bool IsBusyIndicatorVisible
        {
            get { return (bool)GetValue(IsBusyIndicatorVisibleProperty); }
            set { SetValue(IsBusyIndicatorVisibleProperty, value); }
        }
    }
}
