﻿
using System.ComponentModel;
using System.Runtime.CompilerServices;
using System.Threading.Tasks;

namespace crashfix
{
    public abstract class BaseViewModel : INotifyPropertyChanged
    {
        #region Events

        public event PropertyChangedEventHandler PropertyChanged;

        protected void OnPropertyChanged([CallerMemberName] string name = "")
        {
            PropertyChanged?.Invoke(this, new PropertyChangedEventArgs(name));
        }

        #endregion

        public abstract Task Start();

        private bool _isBusyIndicatorVisible;
        public bool IsBusyIndicatorVisible
        {
            get
            {
                return _isBusyIndicatorVisible;
            }
            set
            {
                _isBusyIndicatorVisible = value;
                OnPropertyChanged(nameof(IsBusyIndicatorVisible));
            }
        }
    }
}
